import { forwardRef, memo, useImperativeHandle } from 'react'
import { Form, Input, Select } from 'antd'

export interface DynamicFormRef {
  onSubmit: () => void
}

interface DynamicFormProps {
  formItems?: API.TmplItem[]
  formData?: Record<string, any>
  disabled?: boolean
  setFormData: (data: Record<string, any>) => void
}

const DynamicForm = memo(
  forwardRef<DynamicFormRef, DynamicFormProps>(
    ({ formItems = [], formData = {}, disabled = false, setFormData }, ref) => {
      useImperativeHandle(ref, () => {
        return {
          onSubmit
        }
      })
      console.log(formData)
      console.log(formItems)
      console.log(setFormData)

      const renderField = (field: API.TmplItem) => {
        const options = field.itemStruct
        const { type, label, placeholder, visible, valid, expand, widgetId } = options!
        // if (hidden && hidden(form.getFieldsValue())) return null // 条件渲染
        console.log(visible)
        console.log(valid)

        switch (type) {
          case 'INPUT':
            return (
              <Form.Item name={widgetId} label={label.text} key={widgetId}>
                <Input
                  placeholder={placeholder}
                  maxLength={parseInt((expand as API.FD_COM['INPUT']).maxChars)}
                  showCount
                  prefix={(expand as API.FD_COM['INPUT']).prefix}
                  suffix={(expand as API.FD_COM['INPUT']).suffix}
                />
              </Form.Item>
            )
          case 'SELECT':
            return (
              <Form.Item name={widgetId} label={label.text} key={widgetId}>
                <Select placeholder={placeholder} />
              </Form.Item>
            )
          // 其他组件类型...
          default:
            return null
        }
      }

      const [form] = Form.useForm()
      const onSubmit = () => {
        form.submit()
      }
      const onFinish = (values: any) => {
        console.log('Finish:', values)
      }
      const onFinishFailed = (errorInfo: any) => {
        console.log('Failed:', errorInfo)
      }

      return (
        <Form
          form={form}
          layout='vertical'
          disabled={disabled}
          onFinish={onFinish}
          onFinishFailed={onFinishFailed}>
          {formItems.map(renderField)}
        </Form>
      )
    }
  )
)

export default DynamicForm
